@@ -24,10 +24,10 @@ pub mod camera_request;
 pub use self::camera_request::CameraRequest;
 pub mod camera_type_enum;
 pub use self::camera_type_enum::CameraTypeEnum;
-pub mod cloud_io_t_device;
-pub use self::cloud_io_t_device::CloudIoTDevice;
-pub mod cloud_io_t_device_request;
-pub use self::cloud_io_t_device_request::CloudIoTDeviceRequest;
+pub mod cloudiot_device;
+pub use self::cloudiot_device::CloudiotDevice;
+pub mod cloudiot_device_request;
+pub use self::cloudiot_device_request::CloudiotDeviceRequest;
 pub mod command_enum;
 pub use self::command_enum::CommandEnum;
 pub mod detail_response;
@@ -124,8 +124,8 @@ pub mod paginated_ansible_facts_list;
 pub use self::paginated_ansible_facts_list::PaginatedAnsibleFactsList;
 pub mod paginated_camera_list;
 pub use self::paginated_camera_list::PaginatedCameraList;
-pub mod paginated_cloud_io_t_device_list;
-pub use self::paginated_cloud_io_t_device_list::PaginatedCloudIoTDeviceList;
+pub mod paginated_cloudiot_device_list;
+pub use self::paginated_cloudiot_device_list::PaginatedCloudiotDeviceList;
 pub mod paginated_device_calibration_list;
 pub use self::paginated_device_calibration_list::PaginatedDeviceCalibrationList;
 pub mod paginated_device_list;
@@ -174,8 +174,8 @@ pub mod patched_ansible_facts_request;
 pub use self::patched_ansible_facts_request::PatchedAnsibleFactsRequest;
 pub mod patched_camera_request;
 pub use self::patched_camera_request::PatchedCameraRequest;
-pub mod patched_cloud_io_t_device_request;
-pub use self::patched_cloud_io_t_device_request::PatchedCloudIoTDeviceRequest;
+pub mod patched_cloudiot_device_request;
+pub use self::patched_cloudiot_device_request::PatchedCloudiotDeviceRequest;
 pub mod patched_device_calibration_request;
 pub use self::patched_device_calibration_request::PatchedDeviceCalibrationRequest;
 pub mod patched_device_request;
